@@ -4,8 +4,8 @@
 #include <sys/types.h>
 #include <inttypes.h>
 #include <limits.h>
-#include <linux/gfs2_ondisk.h>
 #include <string.h>
+#include <ncurses.h>
 
 #include "libgfs2.h"
 #include "copyright.cf"
@@ -21,14 +21,10 @@
 enum dsp_mode { HEX_MODE = 0, GFS2_MODE = 1, EXTENDED_MODE = 2, INIT_MODE = 3 };
 #define BLOCK_STACK_SIZE 256
 
-#define pv(struct, member, fmt, fmt2) do {				\
-		print_it("  "#member, fmt, fmt2, struct->member);	\
-	} while (FALSE);
 #define RGLIST_DUMMY_BLOCK -2
 #define JOURNALS_DUMMY_BLOCK -3
 
 extern const char *mtypes[];
-extern struct gfs2_sb sb;
 extern int blockhist;
 extern int edit_mode;
 extern int line;
@@ -47,11 +43,8 @@ extern int edit_row[DMODES], edit_col[DMODES], print_entry_ndx;
 extern int start_row[DMODES], end_row[DMODES], lines_per_row[DMODES];
 extern int edit_size[DMODES], last_entry_onscreen[DMODES];
 extern char edit_fmt[80];
-extern struct gfs2_sbd sbd;
-extern struct gfs_sb *sbd1;
-extern struct gfs2_inum gfs1_quota_di;   /* kludge because gfs2 sb too small */
-extern struct gfs2_inum gfs1_license_di; /* kludge because gfs2 sb too small */
-extern struct gfs2_dinode di;
+extern struct lgfs2_sbd sbd;
+extern struct gfs2_dinode *di;
 extern int screen_chunk_size; /* how much of the 4K can fit on screen */
 extern int gfs2_struct_type;
 extern int identify;
@@ -60,27 +53,33 @@ extern WINDOW *wind;
 extern int editing;
 extern uint64_t temp_blk;
 extern uint64_t starting_blk;
-extern const char *block_type_str[15];
 extern int dsplines;
 extern int dsp_lines[DMODES];
 extern int combined_display;
 extern int details;
 extern const char *allocdesc[2][5];
+extern char *device;
 
-struct gfs2_dirents {
-	uint64_t block;
-	struct gfs2_dirent dirent;
+struct idirent {
+	struct lgfs2_inum inum;
+	uint32_t hash;
+	uint16_t rec_len;
+	uint16_t name_len;
+	uint16_t type;
+	uint16_t rahead;
 	char filename[NAME_MAX];
 };
 
+extern void idirent_in(struct idirent *id, void *de);
+
 struct indirect_info {
 	int is_dir;
 	int height;
 	uint64_t block;
 	uint32_t dirents;
 	struct gfs2_leaf lf;
-	struct metapath mp;
-	struct gfs2_dirents dirent[64];
+	struct lgfs2_metapath mp;
+	struct idirent dirent[64];
 	uint64_t ptroff;
 };
 
@@ -97,7 +96,7 @@ struct blkstack_info {
 	int edit_col[DMODES];
 	enum dsp_mode dmode;
 	int gfs2_struct_type;
-	struct metapath mp;
+	struct lgfs2_metapath mp;
 };
 
 extern struct blkstack_info blockstack[BLOCK_STACK_SIZE];
@@ -129,32 +128,6 @@ static inline int block_is_journals(uint64_t blk)
 #define SCREEN_HEIGHT   (16)
 #define SCREEN_WIDTH    (16)
 
-/* die() used to be in libgfs2.h */
-static __inline__ __attribute__((noreturn, format (printf, 1, 2)))
-void die(const char *fmt, ...)
-{
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
-	exit(-1);
-}
-
-/*  Memory macros  */
-
-#define type_alloc(ptr, type, count) \
-{ \
-  (ptr) = (type *)malloc(sizeof(type) * (count)); \
-  if (!(ptr)) \
-    die("unable to allocate memory on line %d of file %s\n", \
-	__LINE__, __FILE__); \
-}
-
-#define printk printw
-
-/*  Divide x by y.  Round up if there is a remainder.  */
-#define DIV_RU(x, y) (((x) + (y) - 1) / (y))
-
 #define TITLE1 "gfs2_edit - Global File System Editor (use with extreme caution)"
 #define TITLE2 REDHAT_COPYRIGHT " - Press H for help"
 
@@ -223,9 +196,7 @@ extern int block_is_statfs_file(uint64_t blk);
 extern int block_is_quota_file(uint64_t blk);
 extern int block_is_per_node(uint64_t blk);
 extern int display_block_type(char *buf, uint64_t addr, int from_restore);
-extern void gfs_jindex_in(struct gfs_jindex *jindex, char *buf);
-extern void gfs_log_header_in(struct gfs_log_header *head, const char *buf);
-extern void gfs_log_header_print(struct gfs_log_header *lh);
+extern void gfs_log_header_print(void *lhp);
 extern void savemeta(char *out_fn, int saveoption, int gziplevel);
 extern void restoremeta(const char *in_fn, const char *out_device,
 			uint64_t printblocksonly);
@@ -233,7 +204,7 @@ extern int display(int identify_only, int trunc_zeros, uint64_t flagref,
 		   uint64_t ref_blk);
 extern uint64_t check_keywords(const char *kword);
 extern uint64_t masterblock(const char *fn);
-extern void gfs_rgrp_print(struct gfs_rgrp *rg);
+extern void gfs_rgrp_print(void *rgp);
 extern int has_indirect_blocks(void);
 extern const struct lgfs2_metadata *get_block_type(char *buf);
 
