@@ -751,7 +751,6 @@ int ji_update(struct lgfs2_sbd *sdp)
 	struct lgfs2_inode *jip, *ip = sdp->md.jiinode;
 	char journal_name[JOURNAL_NAME_SIZE];
 	int i, error;
-	char buf[sizeof(struct gfs_jindex)];
 
 	if (!ip) {
 		log_crit(_("Journal index inode not found.\n"));
@@ -777,11 +776,10 @@ int ji_update(struct lgfs2_sbd *sdp)
 	memset(journal_name, 0, sizeof(*journal_name));
 	for (i = 0; i < sdp->md.journals; i++) {
 		if (sdp->gfs1) {
-			struct gfs_jindex *ji;
+			struct gfs_jindex ji;
 
-			error = lgfs2_readi(ip,
-					   buf, i * sizeof(struct gfs_jindex),
-					   sizeof(struct gfs_jindex));
+			error = lgfs2_readi(ip, &ji, i * sizeof(struct gfs_jindex),
+			                    sizeof(struct gfs_jindex));
 			if (!error)
 				break;
 			if (error != sizeof(struct gfs_jindex)){
@@ -789,8 +787,7 @@ int ji_update(struct lgfs2_sbd *sdp)
 					" journal index file.\n"));
 				return -1;
 			}
-			ji = (struct gfs_jindex *)buf;
-			sdp->md.journal[i] = lgfs2_inode_read(sdp, be64_to_cpu(ji->ji_addr));
+			sdp->md.journal[i] = lgfs2_inode_read(sdp, be64_to_cpu(ji.ji_addr));
 			if (sdp->md.journal[i] == NULL)
 				return -1;
 		} else {
