@@ -28,10 +28,16 @@ static int metastrcmp(const void *a, const void *b)
 	return strcmp(m1->name, m2->name);
 }
 
-static void print_structs(void)
+static int print_structs(void)
 {
-	const struct lgfs2_metadata *mlist[lgfs2_metadata_size];
+	const struct lgfs2_metadata **mlist;
 	int i;
+
+	mlist = calloc(lgfs2_metadata_size, sizeof(struct lgfs2_metadata *));
+	if (mlist == NULL) {
+		perror("Failed to create metadata type array");
+		return 1;
+	}
 	for (i = 0; i < lgfs2_metadata_size; i++)
 		mlist[i] = &lgfs2_metadata[i];
 
@@ -39,6 +45,8 @@ static void print_structs(void)
 	for (i = 0; i < lgfs2_metadata_size; i++)
 		if (mlist[i]->mh_type != GFS2_METATYPE_NONE)
 			printf("%s\n", mlist[i]->name);
+	free(mlist);
+	return 0;
 }
 
 static void print_fields(const char *name)
@@ -69,8 +77,7 @@ static int getopts(int argc, char *argv[], struct cmdopts *opts)
 			}
 			break;
 		case 'T':
-			print_structs();
-			exit(0);
+			exit(print_structs());
 		case 'F':
 			print_fields(optarg);
 			exit(0);
@@ -97,11 +104,11 @@ static int getopts(int argc, char *argv[], struct cmdopts *opts)
 	return 0;
 }
 
-static int openfs(const char *path, struct gfs2_sbd *sdp)
+static int openfs(const char *path, struct lgfs2_sbd *sdp)
 {
 	int fd;
 	int ret;
-	int sane;
+	int ok;
 	uint64_t count;
 
 	fd = open(path, O_RDWR);
@@ -111,9 +118,9 @@ static int openfs(const char *path, struct gfs2_sbd *sdp)
 	}
 
 	memset(sdp, 0, sizeof(*sdp));
-	sdp->bsize = GFS2_BASIC_BLOCK;
+	sdp->sd_bsize = GFS2_BASIC_BLOCK;
 	sdp->device_fd = fd;
-	ret = compute_constants(sdp);
+	ret = lgfs2_compute_constants(sdp);
 	if (ret != 0) {
 		perror("Bad constants");
 		return 1;
@@ -123,19 +130,19 @@ static int openfs(const char *path, struct gfs2_sbd *sdp)
 		perror("Failed to gather device info");
 		return 1;
 	}
-	fix_device_geometry(sdp);
+	lgfs2_fix_device_geometry(sdp);
 
-	ret = read_sb(sdp);
+	ret = lgfs2_read_sb(sdp);
 	if (ret != 0) {
 		perror("Could not read sb");
 		return 1;
 	}
 
-	sdp->master_dir = lgfs2_inode_read(sdp, sdp->sd_sb.sb_master_dir.no_addr);
-	gfs2_lookupi(sdp->master_dir, "rindex", 6, &sdp->md.riinode);
+	sdp->master_dir = lgfs2_inode_read(sdp, sdp->sd_meta_dir.in_addr);
+	sdp->md.riinode = lgfs2_lookupi(sdp->master_dir, "rindex", 6);
 	sdp->fssize = sdp->device.length;
 	if (sdp->md.riinode) {
-		rindex_read(sdp, 0, &count, &sane);
+		lgfs2_rindex_read(sdp, &count, &ok);
 	} else {
 		perror("Failed to look up rindex");
 		return 1;
@@ -147,7 +154,7 @@ int main(int argc, char *argv[])
 {
 	int ret;
 	struct cmdopts opts = {NULL, NULL};
-	struct gfs2_sbd sbd;
+	struct lgfs2_sbd sbd;
 	struct lgfs2_lang_result *result;
 	struct lgfs2_lang_state *state;
 
@@ -183,13 +190,10 @@ int main(int argc, char *argv[])
 		lgfs2_lang_result_free(&result);
 	}
 
-	gfs2_rgrp_free(&sbd, &sbd.rgtree);
-	inode_put(&sbd.md.riinode);
-	inode_put(&sbd.master_dir);
+	lgfs2_rgrp_free(&sbd, &sbd.rgtree);
+	lgfs2_inode_put(&sbd.md.riinode);
+	lgfs2_inode_put(&sbd.master_dir);
 	lgfs2_lang_free(&state);
 	free(opts.fspath);
 	return 0;
 }
-
-// libgfs2 still requires an external print_it function
-void print_it(const char *label, const char *fmt, const char *fmt2, ...) { return; }
